==> agrosyst-web-0.8.1-sources.jar: fr/inra/agrosyst/web/actions/domains/SolDto.java <==
/*
 * #%L
 * Agrosyst :: Web
 * $Id: SolDto.java 2320 2013-11-28 17:17:49Z echatellier $
 * $HeadURL: https://forge.codelutin.com/svn/agrosyst/tags/agrosyst-0.8.1/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/domains/SolDto.java $
 * %%
 * Copyright (C) 2013 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

package fr.inra.agrosyst.web.actions.domains;

import java.io.Serializable;

/**
 * Sol dto used to edit {@code Sol} in struts (serialized in json).
 * 
 * @author Eric Chatellier
 */
public class SolDto implements Serializable {

    /** serialVersionUID. */
    private static final long serialVersionUID = -5735897928474989471L;

    protected String topiaId;

    protected String name;

    protected String comment;

    protected double importance;

    protected String solArvalisTopiaId;

    protected String solNom;

    protected String solCalcaire;

    protected String solHydromorphie;

    protected String solPierrosite;

    protected String solProfondeur;

    protected String solTexture;

    protected String solRegion;

    protected int solRegionCode;

    protected String solGrenTopiaId;

    public SolDto() {
        
    }

    public SolDto(String topiaId, String name, String comment, double importance) {
        this.topiaId = topiaId;
        this.name = name;
        this.comment = comment;
        this.importance = importance;
    }

    public String getTopiaId() {
        return topiaId;
    }

    public void setTopiaId(String topiaId) {
        this.topiaId = topiaId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public double getImportance() {
        return importance;
    }

    public void setImportance(double importance) {
        this.importance = importance;
    }

    public String getSolArvalisTopiaId() {
        return solArvalisTopiaId;
    }

    public void setSolArvalisTopiaId(String solArvalisTopiaId) {
        this.solArvalisTopiaId = solArvalisTopiaId;
    }

    public String getSolNom() {
        return solNom;
    }

    public void setSolNom(String solNom) {
        this.solNom = solNom;
    }

    public String getSolCalcaire() {
        return solCalcaire;
    }

    public void setSolCalcaire(String solCalcaire) {
        this.solCalcaire = solCalcaire;
    }

    public String getSolHydromorphie() {
        return solHydromorphie;
    }

    public void setSolHydromorphie(String solHydromorphie) {
        this.solHydromorphie = solHydromorphie;
    }

    public String getSolPierrosite() {
        return solPierrosite;
    }

    public void setSolPierrosite(String solPierrosite) {
        this.solPierrosite = solPierrosite;
    }

    public String getSolProfondeur() {
        return solProfondeur;
    }

    public void setSolProfondeur(String solProfondeur) {
        this.solProfondeur = solProfondeur;
    }

    public String getSolTexture() {
        return solTexture;
    }

    public void setSolTexture(String solTexture) {
        this.solTexture = solTexture;
    }

    public String getSolRegion() {
        return solRegion;
    }

    public void setSolRegion(String solRegion) {
        this.solRegion = solRegion;
    }

    public int getSolRegionCode() {
        return solRegionCode;
    }

    public void setSolRegionCode(int solRegionCode) {
        this.solRegionCode = solRegionCode;
    }

    public String getSolGrenTopiaId() {
        return solGrenTopiaId;
    }

    public void setSolGrenTopiaId(String solGrenTopiaId) {
        this.solGrenTopiaId = solGrenTopiaId;
    }
}

==> agrosyst-web-0.11-sources.jar: fr/inra/agrosyst/web/actions/domains/SolDto.java <==
package fr.inra.agrosyst.web.actions.domains;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: SolDto.java 2776 2014-01-18 20:56:29Z athimel $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-0.11/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/domains/SolDto.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import java.io.Serializable;

/**
 * Sol dto used to edit {@code Sol} in struts (serialized in json).
 * 
 * @author Eric Chatellier
 */
public class SolDto implements Serializable {

    /** serialVersionUID. */
    private static final long serialVersionUID = -5735897928474989471L;

    protected String topiaId;

    protected String name;

    protected String comment;

    protected double importance;

    protected String solArvalisTopiaId;

    protected String solNom;

    protected String solCalcaire;

    protected String solHydromorphie;

    protected String solPierrosite;

    protected String solProfondeur;

    protected String solTexture;

    protected String solRegion;

    protected int solRegionCode;

    protected String solGrenTopiaId;

    public SolDto() {
        
    }

    public SolDto(String topiaId, String name, String comment, double importance) {
        this.topiaId = topiaId;
        this.name = name;
        this.comment = comment;
        this.importance = importance;
    }

    public String getTopiaId() {
        return topiaId;
    }

    public void setTopiaId(String topiaId) {
        this.topiaId = topiaId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public double getImportance() {
        return importance;
    }

    public void setImportance(double importance) {
        this.importance = importance;
    }

    public String getSolArvalisTopiaId() {
        return solArvalisTopiaId;
    }

    public void setSolArvalisTopiaId(String solArvalisTopiaId) {
        this.solArvalisTopiaId = solArvalisTopiaId;
    }

    public String getSolNom() {
        return solNom;
    }

    public void setSolNom(String solNom) {
        this.solNom = solNom;
    }

    public String getSolCalcaire() {
        return solCalcaire;
    }

    public void setSolCalcaire(String solCalcaire) {
        this.solCalcaire = solCalcaire;
    }

    public String getSolHydromorphie() {
        return solHydromorphie;
    }

    public void setSolHydromorphie(String solHydromorphie) {
        this.solHydromorphie = solHydromorphie;
    }

    public String getSolPierrosite() {
        return solPierrosite;
    }

    public void setSolPierrosite(String solPierrosite) {
        this.solPierrosite = solPierrosite;
    }

    public String getSolProfondeur() {
        return solProfondeur;
    }

    public void setSolProfondeur(String solProfondeur) {
        this.solProfondeur = solProfondeur;
    }

    public String getSolTexture() {
        return solTexture;
    }

    public void setSolTexture(String solTexture) {
        this.solTexture = solTexture;
    }

    public String getSolRegion() {
        return solRegion;
    }

    public void setSolRegion(String solRegion) {
        this.solRegion = solRegion;
    }

    public int getSolRegionCode() {
        return solRegionCode;
    }

    public void setSolRegionCode(int solRegionCode) {
        this.solRegionCode = solRegionCode;
    }

    public String getSolGrenTopiaId() {
        return solGrenTopiaId;
    }

    public void setSolGrenTopiaId(String solGrenTopiaId) {
        this.solGrenTopiaId = solGrenTopiaId;
    }
}
